@@ -1,3 +1,4 @@
+from .activity_log import ActivityLog as ActivityLog, ActivityLogResponse as ActivityLogResponse
 from .applied_coupon import AppliedCoupon as AppliedCoupon
 from .billable_metric import (
     BillableMetric as BillableMetric,
@@ -88,6 +89,7 @@ from .wallet import (
     RecurringTransactionRuleList as RecurringTransactionRuleList,
     RecurringTransactionRuleResponse as RecurringTransactionRuleResponse,
     RecurringTransactionRuleResponseList as RecurringTransactionRuleResponseList,
+    AppliesTo as AppliesTo,
 )
 from .wallet_transaction import WalletTransaction as WalletTransaction
 from .webhook_endpoint import WebhookEndpoint as WebhookEndpoint
