@@ -14,6 +14,7 @@ class RecurringTransactionRule(BaseModel):
     paid_credits: Optional[str]
     granted_credits: Optional[str]
     started_at: Optional[str]
+    expiration_at: Optional[str]
     target_ongoing_balance: Optional[str]
     transaction_metadata: Optional[List[Dict[str, str]]]
 
@@ -27,6 +28,8 @@ class RecurringTransactionRuleResponse(BaseModel):
     paid_credits: Optional[str]
     granted_credits: Optional[str]
     started_at: Optional[str]
+    expiration_at: Optional[str]
+    status: Optional[str]
     target_ongoing_balance: Optional[str]
     created_at: Optional[str]
     transaction_metadata: Optional[List[Dict[str, str]]]
@@ -40,6 +43,10 @@ class RecurringTransactionRuleResponseList(BaseModel):
     __root__: List[RecurringTransactionRuleResponse]
 
 
+class AppliesTo(BaseModel):
+    fee_types: Optional[List[str]]
+
+
 class Wallet(BaseModel):
     external_customer_id: Optional[str]
     rate_amount: Optional[str]
@@ -50,6 +57,7 @@ class Wallet(BaseModel):
     currency: Optional[str]
     recurring_transaction_rules: Optional[RecurringTransactionRuleList]
     transaction_metadata: Optional[List[Dict[str, str]]]
+    applies_to: Optional[AppliesTo]
 
 
 class WalletResponse(BaseResponseModel):
@@ -73,3 +81,4 @@ class WalletResponse(BaseResponseModel):
     ongoing_usage_balance_cents: int
     credits_ongoing_balance: str
     credits_ongoing_usage_balance: str
+    applies_to: Optional[AppliesTo]
